yakumo.neutron.v2.subnet_pool.Manager

Package yakumo :: Package neutron :: Package v2 :: Module subnet_pool :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for subnet pools in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for subnet pools in Compute API v2

Instance Methods | [hide private]
yakumo.neutron.v2.subnet_pool.Resource |
create(self, name=`'``__UNDEF__``'`, address_scope_id=`'``__UNDEF__``'`, prefixes=`'``__UNDEF__``'`, default_prefixlen=`'``__UNDEF__``'`, min_prefixlen=`'``__UNDEF__``'`, max_prefixlen=`'``__UNDEF__``'`, default_quota=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_shared=`'``__UNDEF__``'`) Create a subnet pool | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``subnetpool``'``
| _json_resources_key = ``'``subnetpools``'``
| _url_resource_path = ``'``/v2.0/subnetpools``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, address_scope_id=`'``__UNDEF__``'`, prefixes=`'``__UNDEF__``'`, default_prefixlen=`'``__UNDEF__``'`, min_prefixlen=`'``__UNDEF__``'`, max_prefixlen=`'``__UNDEF__``'`, default_quota=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_shared=`'``__UNDEF__``'`) | source code
Create a subnet pool Parameters: `name` (str) - Subnet pool name `address_scope_id` (str) - UUID of address scope `prefixes` ([str]) - a list of subnets `default_prefixlen` (int) - Default prefix length `min_prefixlen` (int) - Minimum prefix length `max_prefixlen` (int) - Maximum prefix length `default_quota` (int) - Default quota `project` (yakumo.porject.Resource) - Project `is_shared` (bool) - Whether the subnet pool is shared Returns: yakumo.neutron.v2.subnet_pool.Resource Created subnet pool Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('prefixes'
      , 'prefixes', mapper.Noop), ('ip_version', 'ip_version', mapper.Noop),
       ('min_prefixlen', 'min_prefixlen', mapper.Noop), ('default_prefixlen'
      , 'default_prefixlen', mapper.Noop), ('max_prefixlen', 'max_prefixlen'
      , mapper.Noop), ('default_quota', 'default_quota', mapper.Noop), ('is_
      shared', 'shared', mapper.Noop,), ('address_scope_id', 'address_scope_
      id', mapper.Noop), ('project', 'tenant_id', mapper.Resource('project')
      ),]